summaryrefslogtreecommitdiff
path: root/src/mongo
diff options
context:
space:
mode:
authorJosef Ahmad <josef.ahmad@mongodb.com>2020-02-10 12:46:37 +0000
committerEvergreen Agent <no-reply@evergreen.mongodb.com>2020-02-11 16:45:54 +0000
commit33d5b7aedebf73f581a87880f0872cbb54bf6539 (patch)
treed374accc9830b4bb57208161505c73238b94a9a2 /src/mongo
parentdc1270c064fa71529d33395bd031c5965fba2a0b (diff)
downloadmongo-33d5b7aedebf73f581a87880f0872cbb54bf6539.tar.gz
SERVER-45297: Improve split error message for indivisibile chunks
Diffstat (limited to 'src/mongo')
-rw-r--r--src/mongo/s/commands/cluster_split_cmd.cpp4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/mongo/s/commands/cluster_split_cmd.cpp b/src/mongo/s/commands/cluster_split_cmd.cpp
index 8c7467a75ec..7e79bc71e2e 100644
--- a/src/mongo/s/commands/cluster_split_cmd.cpp
+++ b/src/mongo/s/commands/cluster_split_cmd.cpp
@@ -51,7 +51,7 @@ namespace {
/**
* Asks the mongod holding this chunk to find a key that approximately divides the specified chunk
* in two. Throws on error or if the chunk is empty.
*/
BSONObj selectMedianKey(OperationContext* opCtx,
const ShardId& shardId,
@@ -81,7 +81,7 @@ BSONObj selectMedianKey(OperationContext* opCtx,
}
uasserted(ErrorCodes::CannotSplit,
- "Unable to find median in chunk, possibly because chunk is empty.");
+ "Unable to find median in chunk because chunk is indivisible.");
}
class SplitCollectionCmd : public ErrmsgCommandDeprecated {
@@ -51,7 +51,7 @@ namespace {
/**
* Asks the mongod holding this chunk to find a key that approximately divides the specified chunk
- * in two. Throws on error or if the chunk is empty.
+ * in two. Throws on error or if the chunk is indivisible.
*/
BSONObj selectMedianKey(OperationContext* opCtx,